<a id="mypy-boto3"></a>

# mypy-boto3

[![PyPI - mypy-boto3](https://img.shields.io/pypi/v/mypy-boto3.svg?color=blue)](https://pypi.org/project/mypy-boto3)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3.svg?color=blue)](https://pypi.org/project/mypy-boto3)
[![Docs](https://img.shields.io/readthedocs/boto3-stubs.svg?color=blue)](https://youtype.github.io/boto3_stubs_docs/)
[![PyPI - Downloads](https://static.pepy.tech/badge/mypy-boto3)](https://pepy.tech/project/mypy-boto3)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Dynamic
[boto3 1.34.157](https://boto3.amazonaws.com/v1/documentation/api/1.34.157/index.html)
type annotations builder for
[boto3-stubs](https://pypi.org/project/boto3-stubs/).

Generated by
[mypy-boto3-builder 7.25.0](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3](#mypy-boto3)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

```bash
# Install this package
python -m pip install mypy-boto3

# Install type annotations for boto3 services you use
python -m pip install 'boto3-stubs[s3,ec2]'

# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'boto3-stubs-lite[s3,ec2]'
```

<a id="usage"></a>

## Usage

Provides `ServiceName` and `ResourceServiceName` literals:

```python
from typing import overload

import boto3
from botocore.client import BaseClient
from mypy_boto3.literals import ServiceName
from mypy_boto3_ec2.client import EC2Client
from mypy_boto3_ec2.literals import EC2ServiceName
from mypy_boto3_s3.client import S3Client
from mypy_boto3_s3.literals import S3ServiceName


@overload
def get_client(service_name: EC2ServiceName) -> EC2Client: ...


@overload
def get_client(service_name: S3ServiceName) -> S3Client: ...


@overload
def get_client(service_name: ServiceName) -> BaseClient: ...


def get_client(service_name: ServiceName) -> BaseClient:
    return boto3.client(service_name)


# type: S3Client, fully type annotated
# All methods and attributes are auto-completed and type checked
s3_client = get_client("s3")

# type: EC2Client, fully type annotated
# All methods and attributes are auto-completed and type checked
ec2_client = get_client("ec2")

# type: BaseClient, only basic type annotations
# Dynamodb-specific methods and attributes are not auto-completed and not type checked
dynamodb_client = get_client("dynamodb")
```

<a id="latest-changes"></a>

### Latest changes

Full changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`mypy-boto3` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="support-and-contributing"></a>

## Support and contributing

Please reports any bugs or request new features in
[mypy_boto3_builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
